@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2015-2023 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -21,9 +21,7 @@ CategoryTypeComboBox::CategoryTypeComboBox(bool customType, QWidget *parent)
     }
 }
 
-CategoryTypeComboBox::~CategoryTypeComboBox()
-{
-}
+CategoryTypeComboBox::~CategoryTypeComboBox() = default;
 
 void CategoryTypeComboBox::restoreToDefault()
 {
