@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2019-2022 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2019-2023 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -77,7 +77,7 @@ bool ChangeDebugModeJob::start()
     return true;
 }
 
-LoggingCategory::LoggingType ChangeDebugModeJob::convertDebugModeToLoggingType(const QString &value)
+LoggingCategory::LoggingType ChangeDebugModeJob::convertDebugModeToLoggingType(const QString &value) const
 {
     if (value == QLatin1String("Full")) {
         return LoggingCategory::LoggingType::All;
@@ -125,9 +125,8 @@ void ChangeDebugModeJob::setLoggingCategoriesName(const QStringList &loggingCate
 
 bool ChangeDebugModeJob::debugModeIsValid(const QString &value) const
 {
-    if (value == QLatin1String("Full") || value == QLatin1String("Info") || value == QLatin1String("Warning") || value == QLatin1String("Critical")
-        || value == QLatin1String("Off")) {
-        return true;
+    if (convertDebugModeToLoggingType(value) == LoggingCategory::LoggingType::Undefined) {
+        return false;
     }
-    return false;
+    return true;
 }
