@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2019-2022 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2019-2023 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -28,7 +28,7 @@ public:
 
     Q_REQUIRED_RESULT bool canStart() const;
     Q_REQUIRED_RESULT bool debugModeIsValid(const QString &value) const;
-    Q_REQUIRED_RESULT LoggingCategory::LoggingType convertDebugModeToLoggingType(const QString &value);
+    Q_REQUIRED_RESULT LoggingCategory::LoggingType convertDebugModeToLoggingType(const QString &value) const;
     void setWithoutArguments(bool b);
     Q_REQUIRED_RESULT bool withoutArguments() const;
 
