@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2015-2023 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -79,6 +79,8 @@ Q_REQUIRED_RESULT LIBKDEBUGSETTINGS_EXPORT_TEST_EXPORT RenameCategory::List read
 Q_REQUIRED_RESULT LIBKDEBUGSETTINGS_EXPORT LoggingCategory::LoggingType convertCategoryTypeFromString(const QString &str);
 Q_REQUIRED_RESULT LIBKDEBUGSETTINGS_EXPORT QString convertCategoryTypeToString(LoggingCategory::LoggingType type);
 Q_REQUIRED_RESULT LIBKDEBUGSETTINGS_EXPORT QString qtFileName();
+Q_REQUIRED_RESULT LIBKDEBUGSETTINGS_EXPORT bool hasWritableGroups();
+Q_REQUIRED_RESULT LIBKDEBUGSETTINGS_EXPORT QStringList groupFileList();
 }
 
 Q_DECLARE_METATYPE(KDebugSettingsUtil::LoadLoggingCategory::LogType)
