@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2020-2021 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2020-2023 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -27,9 +27,7 @@ LoadToolButton::LoadToolButton(QWidget *parent)
     mainMenu->addMenu(mLoadMenu);
 }
 
-LoadToolButton::~LoadToolButton()
-{
-}
+LoadToolButton::~LoadToolButton() = default;
 
 void LoadToolButton::updateLoadGroupMenu()
 {
